/**
 * @name 常量
 * @description 多环境配置
 * @param {Boolean}  debug          是否开启debug模式
 * @param {Object}   env            当前的项目环境配置
 * @param {Object}   systemInfo     当前的系统信息
 * @param {Boolean}  isIPhone       判断机型是否是iPhone
 * @param {Boolean}  isIPhoneX      判断机型是否是iPhoneX系列
 * @param {Boolean}  menu           小程序顶部胶囊按钮的信息
 * @param {Object}  locationInfo    用户的当前位置信息
 */
import env from './env';

import amap from "@/lib/wx-map-sdk/amap-wx.130.js";
function getLocationInfo() {
  const info = {};
  uni.getLocation(function(res) {
    console.log('纬度：' + res.latitude);
    console.log('经度：' + res.longitude);
  });
  const myAmapFun = new amap.AMapWX({
      key: env.aMapKey
  });
  myAmapFun.getRegeo({
      success: function (res) {
          if (!res.length) {
              return;
          }
          Object.assign(info, res[0]);
      },
      fail: function (info) {
          uni.showModal({
              title: info.errMsg
          });
      }
  });
  return info;
}
export default {
  data() {
    return {};
  },
  debug: true,
  env,
  systemInfo: uni.getSystemInfoSync(),
  menu: uni.getSystemInfoSync(),
  isIPhone: uni.getSystemInfoSync().model.indexOf('iPhone') >= 0,
  isIPhoneX: uni.getSystemInfoSync().model.lastIndexOf('X') >= 0,
  locationInfo: getLocationInfo()
};